"use strict";
/**
 * Copyright © 2018 Emu Analytics
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.AuthEndpoints = void 0;
var user_endpoints_1 = require("./user.endpoints");
var AuthEndpoints = /** @class */ (function () {
    function AuthEndpoints(client) {
        this.client = client;
        this.users = new user_endpoints_1.UserEndpoint(this.client);
    }
    AuthEndpoints.prototype.login = function (email, password, applicationId) {
        return this.client._post('/api/v1/auth/login', { email: email, password: password, applicationId: applicationId });
    };
    AuthEndpoints.prototype.logout = function (accessToken, refreshToken) {
        return this.client._post('/api/v1/auth/logout', { refreshToken: refreshToken }, {
            headers: { Authorization: "Bearer ".concat(accessToken) }
        });
    };
    AuthEndpoints.prototype.refresh = function (refreshToken, applicationId) {
        return this.client._post('/api/v1/auth/refresh', { refreshToken: refreshToken, applicationId: applicationId });
    };
    AuthEndpoints.prototype.changePassword = function (password, newPassword, token) {
        return this.client._post('/api/v1/auth/changepassword', {
            password: password,
            newPassword: newPassword
        }, {
            headers: { Authorization: "Bearer ".concat(token) }
        });
    };
    AuthEndpoints.prototype.signUp = function (firstName, lastName, email, password, applicationId, confirmUrl, redirectUrl) {
        // Support legacy signature, which was missing confirmUrl
        if (!redirectUrl) {
            redirectUrl = confirmUrl;
            confirmUrl = "".concat(this.client.baseUrl, "/api/v1/auth/confirmsignup");
        }
        return this.client._post('/api/v1/auth/signup', {
            firstName: firstName,
            lastName: lastName,
            email: email,
            password: password,
            applicationId: applicationId,
            confirmUrl: confirmUrl,
            redirectUrl: redirectUrl
        });
    };
    AuthEndpoints.prototype.confirmSignUp = function (email, token, redirect) {
        return this.client._get("/api/v1/auth/confirmsignup", { params: { email: email, token: token, redirect: redirect } });
    };
    AuthEndpoints.prototype.requestPasswordReset = function (email, applicationId, redirectUrl) {
        return this.client._post('/api/v1/auth/requestpasswordreset', { email: email, applicationId: applicationId, redirectUrl: redirectUrl });
    };
    AuthEndpoints.prototype.resetPassword = function (email, password, applicationId, token) {
        return this.client._post('/api/v1/auth/resetpassword', { email: email, password: password, applicationId: applicationId, token: token });
    };
    return AuthEndpoints;
}());
exports.AuthEndpoints = AuthEndpoints;
//# sourceMappingURL=auth.edpoints.js.map