"use strict";
/**
 * Copyright © 2018 Emu Analytics
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.BaseEndpoints = void 0;
var BaseEndpoints = /** @class */ (function () {
    function BaseEndpoints(client, resourcePath) {
        this.client = client;
        this.resourcePath = resourcePath;
    }
    Object.defineProperty(BaseEndpoints.prototype, "resourceEndpoint", {
        get: function () {
            return "/api/v1/".concat(this.resourcePath);
        },
        enumerable: false,
        configurable: true
    });
    BaseEndpoints.prototype.list = function (params) {
        // Reformat filter for query string
        if (params === null || params === void 0 ? void 0 : params.filter) {
            var filter_1 = params.filter;
            Object.keys(filter_1).forEach(function (key) {
                params["filter[".concat(key, "]")] = filter_1[key];
            });
            delete params.filter;
        }
        return this.client._get(this.resourceEndpoint, { params: params });
    };
    BaseEndpoints.prototype.get = function (id, params) {
        if (params === void 0) { params = {}; }
        return this.client._get("".concat(this.resourceEndpoint, "/").concat(id), { params: params });
    };
    BaseEndpoints.prototype.create = function (data, params) {
        if (params === void 0) { params = {}; }
        return this.client._post("".concat(this.resourceEndpoint), data, { params: params });
    };
    BaseEndpoints.prototype.update = function (id, data, params) {
        if (params === void 0) { params = {}; }
        return this.client._put("".concat(this.resourceEndpoint, "/").concat(id), data, { params: params });
    };
    BaseEndpoints.prototype.delete = function (id, params) {
        if (params === void 0) { params = {}; }
        return this.client._delete("".concat(this.resourceEndpoint, "/").concat(id), { params: params });
    };
    BaseEndpoints.prototype.getMetadata = function (id, key, params) {
        if (params === void 0) { params = {}; }
        var endpoint = key
            ? "".concat(this.resourceEndpoint, "/").concat(id, "/metadata/").concat(key)
            : "".concat(this.resourceEndpoint, "/").concat(id, "/metadata");
        return this.client._get(endpoint, { params: params });
    };
    BaseEndpoints.prototype.setMetadata = function (id, key, value, params) {
        if (params === void 0) { params = {}; }
        // Wrap primitives in value object
        if (typeof value === 'string' || typeof value === 'number' || typeof value === 'boolean') {
            value = { value: value };
        }
        return this.client._put("".concat(this.resourceEndpoint, "/").concat(id, "/metadata/").concat(key), value, {
            headers: {
                'Content-Type': 'application/json'
            },
            params: params
        });
    };
    BaseEndpoints.prototype.deleteMetadata = function (id, key, params) {
        if (params === void 0) { params = {}; }
        return this.client._delete("".concat(this.resourceEndpoint, "/").concat(id, "/metadata/").concat(key), {
            headers: {
                'Content-Type': 'application/json'
            },
            params: params
        });
    };
    return BaseEndpoints;
}());
exports.BaseEndpoints = BaseEndpoints;
//# sourceMappingURL=base.endpoints.js.map