"use strict";
/**
 * Copyright © 2018 Emu Analytics
 */
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Client = void 0;
var axios_1 = __importDefault(require("axios"));
var debug_1 = __importDefault(require("debug"));
var apikey_endpoints_1 = require("./apikey.endpoints");
var appconfig_endpoints_1 = require("./appconfig.endpoints");
var application_endpoints_1 = require("./application.endpoints");
var auth_edpoints_1 = require("./auth.edpoints");
var database_endpoints_1 = require("./database.endpoints");
var dataset_endpoints_1 = require("./dataset.endpoints");
var errors_1 = require("./errors");
var job_endpoints_1 = require("./job.endpoints");
var map_endoints_1 = require("./map.endoints");
var maplayer_endpoints_1 = require("./maplayer.endpoints");
var pipeline_endpoints_1 = require("./pipeline.endpoints");
var style_endpoint_1 = require("./style.endpoint");
var tile_source_endpoints_1 = require("./tile-source.endpoints");
var tile_endpoints_1 = require("./tile.endpoints");
var upload_endpoints_1 = require("./upload.endpoints");
var web_socket_gateway_1 = require("./web-socket-gateway");
var Client = /** @class */ (function () {
    function Client(baseUrl, apiKey, options) {
        if (apiKey === void 0) { apiKey = null; }
        this.baseUrl = baseUrl;
        this.apiKey = apiKey;
        this.debug = (0, debug_1.default)('flow-engine-client');
        this.accessToken = null;
        this.auth = new auth_edpoints_1.AuthEndpoints(this);
        this.tiles = new tile_endpoints_1.TileEndpoints(this);
        this.maps = new map_endoints_1.MapEndpoints(this);
        this.apiKeys = new apikey_endpoints_1.ApiKeyEndpoints(this);
        this.applications = new application_endpoints_1.ApplicationEndpoints(this);
        this.appconfig = new appconfig_endpoints_1.AppConfigEndpoints(this);
        this.databases = new database_endpoints_1.DatabaseEndpoints(this);
        this.datasets = new dataset_endpoints_1.DatasetEndpoints(this);
        this.styles = new style_endpoint_1.StyleEndpoints(this);
        this.tileSources = new tile_source_endpoints_1.TileSourceEndpoints(this);
        this.uploads = new upload_endpoints_1.UploadEndpoints(this);
        this.jobs = new job_endpoints_1.JobEndpoints(this);
        this.maplayers = new maplayer_endpoints_1.MapLayerEndpoints(this);
        this.pipelines = new pipeline_endpoints_1.PipelineEndpoints(this);
        this.axios = axios_1.default.create({
            baseURL: baseUrl,
            maxContentLength: 524288000,
            transformResponse: [
                function transformResponse(data, headers) {
                    var _a;
                    if ((_a = headers === null || headers === void 0 ? void 0 : headers['content-type']) === null || _a === void 0 ? void 0 : _a.startsWith('application/json')) {
                        // Force parsing of data if expected content type is JSON
                        // This ensures that errors are thrown if JSON is truncated due to a query timeout
                        // (default Axios behavior is simply to return a string if JSON parsing fails)
                        return JSON.parse(data);
                    }
                    return data;
                }
            ]
        });
        this.webSocketGateway = new web_socket_gateway_1.WebSocketGateway(this, options);
    }
    Client.prototype.connect = function () {
        return this.webSocketGateway.connect();
    };
    Client.prototype.disconnect = function () {
        return this.webSocketGateway.disconnect();
    };
    Client.prototype.config = function () {
        return this._get('/api/v1/config');
    };
    Client.prototype._get = function (path, options) {
        var _a;
        if (options === void 0) { options = {}; }
        // Move apiKey from params
        if ((_a = options.params) === null || _a === void 0 ? void 0 : _a.apiKey) {
            options.apiKey = options.params.apiKey;
            delete options.params.apiKey;
        }
        return this.axios(__assign(__assign({ method: 'get', url: path }, options), this.headers(options)))
            .then(function (res) { return res.data; })
            .catch(this.handleError);
    };
    Client.prototype._post = function (path, data, options) {
        var _a;
        if (options === void 0) { options = {}; }
        // Move apiKey from params
        if ((_a = options.params) === null || _a === void 0 ? void 0 : _a.apiKey) {
            options.apiKey = options.params.apiKey;
            delete options.params.apiKey;
        }
        return this.axios(__assign(__assign({ method: 'post', url: path, data: data, maxContentLength: Infinity, maxBodyLength: Infinity }, options), this.headers(options)))
            .then(function (res) { return res.data; })
            .catch(this.handleError);
    };
    Client.prototype._put = function (path, data, options) {
        var _a;
        if (options === void 0) { options = {}; }
        // Move apiKey from params
        if ((_a = options.params) === null || _a === void 0 ? void 0 : _a.apiKey) {
            options.apiKey = options.params.apiKey;
            delete options.params.apiKey;
        }
        return this.axios(__assign(__assign({ method: 'put', url: path, data: data }, options), this.headers(options)))
            .then(function (res) { return res.data; })
            .catch(this.handleError);
    };
    Client.prototype._delete = function (path, options) {
        var _a;
        if (options === void 0) { options = {}; }
        // Move apiKey from params
        if ((_a = options.params) === null || _a === void 0 ? void 0 : _a.apiKey) {
            options.apiKey = options.params.apiKey;
            delete options.params.apiKey;
        }
        return this.axios(__assign(__assign({ method: 'delete', url: path }, options), this.headers(options)))
            .then(function (res) { return res.data; })
            .catch(this.handleError);
    };
    // Subscribe to named channel - errors and messages are delivered via the callback
    Client.prototype._subscribe = function (channel, cb) {
        if (!this.webSocketGateway.isConnected) {
            this.webSocketGateway.connect();
        }
        return this.webSocketGateway.subscribe(channel, cb);
    };
    // Unsubscribe from named channel - optional callback is called on completion
    Client.prototype._unsubscribe = function (channel, cb) {
        if (!this.webSocketGateway.isConnected) {
            this.webSocketGateway.connect();
        }
        this.webSocketGateway.unsubscribe(channel, cb);
    };
    /**
     * Normalize errors
     * Throws a new error based on type of input error
     *
     * @param {AxiosError} e
     */
    Client.prototype.handleError = function (e) {
        // Flow API error
        if (e.response && e.response.data) {
            if (typeof e.response.data === 'object') {
                var data = e.response.data;
                throw new errors_1.FlowEngineError(data.message || data.error, data.error, e.response.status);
            }
            else if (typeof e.response.data === 'string') {
                throw new errors_1.FlowEngineError(e.response.data, null, e.response.status);
            }
        }
        // Generic error
        // Don't leak information in error
        var cleanError = e;
        delete cleanError.config;
        delete cleanError.request;
        delete cleanError.response;
        throw new errors_1.FlowEngineError(cleanError.message, cleanError);
    };
    Client.prototype.headers = function (options) {
        var headers = options.headers || {};
        if (options.apiKey || this.apiKey) {
            headers['X-Api-Key'] = options.apiKey || this.apiKey;
        }
        // Add default auth header if token supplied and not already set in options
        if (this.accessToken) {
            headers.Authorization = headers.Authorization || "Bearer ".concat(this.accessToken);
        }
        return { headers: headers };
    };
    return Client;
}());
exports.Client = Client;
//# sourceMappingURL=client.js.map