"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.WebSocketGateway = exports.WebSocketChannel = void 0;
var socket_io_client_1 = require("socket.io-client");
var WebSocketChannel;
(function (WebSocketChannel) {
    WebSocketChannel["System"] = "system";
    WebSocketChannel["AppConfig"] = "appconfig";
    WebSocketChannel["Dataset"] = "dataset/";
})(WebSocketChannel || (exports.WebSocketChannel = WebSocketChannel = {}));
var WebSocketGateway = /** @class */ (function () {
    function WebSocketGateway(client, options) {
        this.client = client;
        this.options = options;
        this.connected = false;
        this.subscribedChannels = new Set();
    }
    Object.defineProperty(WebSocketGateway.prototype, "isConnected", {
        get: function () {
            return this.connected;
        },
        enumerable: false,
        configurable: true
    });
    WebSocketGateway.prototype.connect = function () {
        var _this = this;
        if (this.isConnected) {
            return Promise.resolve();
        }
        return new Promise(function (resolve, reject) {
            var socket = (0, socket_io_client_1.io)(_this.client.baseUrl, __assign(__assign({}, _this.options), { autoConnect: false, auth: function (cb) {
                    var authHeaders = {};
                    if (_this.client.apiKey) {
                        authHeaders['x-api-key'] = _this.client.apiKey;
                    }
                    if (_this.client.accessToken) {
                        authHeaders['x-socket-token'] = "Bearer ".concat(_this.client.accessToken);
                    }
                    cb(authHeaders);
                } }));
            socket.on('connect', function () {
                _this.client.debug("Socket connected: ".concat(socket.id));
                if (_this.subscribedChannels.size) {
                    _this.subscribedChannels.forEach(function (channel) {
                        socket.emit('subscribe', { channel: channel }, function (resp) {
                            if (resp.status === 'error') {
                                console.error("Error re-subscribing to channel '".concat(channel), resp);
                            }
                            else {
                                _this.client.debug("Re-subscribed to channel '".concat(channel));
                            }
                        });
                    });
                }
            });
            socket.io.on('reconnect_attempt', function (attempt) {
                _this.client.debug("Socket reconnect attempt: ".concat(attempt));
            });
            socket.io.on('reconnect_error', function (error) {
                _this.client.debug("Socket reconnect error: ".concat(error.message));
            });
            socket.io.on('reconnect_failed', function () {
                _this.client.debug("Socket reconnect failed");
            });
            socket.io.on('reconnect', function () {
                _this.client.debug("Socket reconnected");
            });
            socket.on('disconnect', function (reason) {
                _this.client.debug("Socket disconnected: ".concat(reason));
            });
            socket.on('error', function (e) {
                _this.client.debug("Socket error: ".concat(e.messaage));
            });
            _this.socket = socket;
            _this.connected = true;
            socket.on('connect', function () {
                resolve();
            });
            socket.connect();
        });
    };
    WebSocketGateway.prototype.disconnect = function () {
        var _this = this;
        if (!this.isConnected) {
            return Promise.resolve();
        }
        return new Promise(function (resolve) {
            _this.socket.once('disconnect', function () {
                _this.connected = false;
                resolve();
            });
            _this.socket.disconnect();
        });
    };
    WebSocketGateway.prototype.subscribe = function (channel, cb) {
        var _this = this;
        if (!this.isConnected) {
            throw new Error('WebSocketGateway is not initialized');
        }
        this.client.debug("Subscribing to channel '".concat(channel));
        // Discriminating 'message' event listener that only responds to messages sent to 'channel'
        var listener = function (msg) {
            if (msg.channel === channel) {
                cb(null, msg);
            }
        };
        // Unsubscriber
        var unsubscribe = function (unsubscribeCb) {
            _this.socket.off('message', listener);
            _this.unsubscribe(channel, unsubscribeCb);
        };
        // Subscribe and bind listener
        this.socket.emit('subscribe', { channel: channel }, function (resp) {
            if (resp.status === 'error') {
                _this.client.debug("Error subscribed to channel '".concat(channel), resp);
                return cb(new Error(resp.message));
            }
            _this.subscribedChannels.add(channel);
            _this.client.debug("Subscribed to channel '".concat(channel));
            _this.socket.on('message', listener);
        });
        return unsubscribe;
    };
    WebSocketGateway.prototype.unsubscribe = function (channel, cb) {
        var _this = this;
        if (!this.isConnected) {
            throw new Error('WebSocketGateway is not initialized');
        }
        this.client.debug("Unsubscribing from channel '".concat(channel));
        this.socket.emit('unsubscribe', { channel: channel }, function (resp) {
            if (resp.status === 'error') {
                _this.client.debug("Error unsubscribing from channel '".concat(channel), resp);
                if (cb) {
                    cb(new Error(resp.message));
                }
            }
            else {
                _this.subscribedChannels.delete(channel);
                _this.client.debug("Unsubscribed from channel '".concat(channel));
                if (cb) {
                    cb(null);
                }
            }
        });
    };
    return WebSocketGateway;
}());
exports.WebSocketGateway = WebSocketGateway;
//# sourceMappingURL=web-socket-gateway.js.map