/**
 * Copyright © 2018 Emu Analytics
 */
import Debug from 'debug';
import { IConfig } from './api-interfaces';
import { ApiKeyEndpoints } from './apikey.endpoints';
import { AppConfigEndpoints } from './appconfig.endpoints';
import { ApplicationEndpoints } from './application.endpoints';
import { AuthEndpoints } from './auth.edpoints';
import { DatabaseEndpoints } from './database.endpoints';
import { DatasetEndpoints } from './dataset.endpoints';
import { JobEndpoints } from './job.endpoints';
import { MapEndpoints } from './map.endoints';
import { MapLayerEndpoints } from './maplayer.endpoints';
import { PipelineEndpoints } from './pipeline.endpoints';
import { StyleEndpoints } from './style.endpoint';
import { TileSourceEndpoints } from './tile-source.endpoints';
import { TileEndpoints } from './tile.endpoints';
import { UploadEndpoints } from './upload.endpoints';
import { WebSocketGateway, WebSocketManagerOptions, WebSocketSubscribeCallback, WebSocketUnsubscribeCallback, WebSocketUnsubscriber } from './web-socket-gateway';
export type ClientOptions = WebSocketManagerOptions;
export declare class Client {
    baseUrl: string;
    readonly apiKey: string | null;
    private readonly axios;
    readonly debug: Debug.Debugger;
    webSocketGateway: WebSocketGateway;
    accessToken: string | null;
    auth: AuthEndpoints;
    tiles: TileEndpoints;
    maps: MapEndpoints;
    apiKeys: ApiKeyEndpoints;
    applications: ApplicationEndpoints;
    appconfig: AppConfigEndpoints;
    databases: DatabaseEndpoints;
    datasets: DatasetEndpoints;
    styles: StyleEndpoints;
    tileSources: TileSourceEndpoints;
    uploads: UploadEndpoints;
    jobs: JobEndpoints;
    maplayers: MapLayerEndpoints;
    pipelines: PipelineEndpoints;
    constructor(baseUrl: string, apiKey?: string | null, options?: ClientOptions);
    connect(): Promise<void>;
    disconnect(): Promise<void>;
    config(): Promise<IConfig>;
    _get(path: string, options?: any): Promise<any>;
    _post(path: string, data: object, options?: any): Promise<any>;
    _put(path: string, data: object, options?: any): Promise<any>;
    _delete(path: string, options?: any): Promise<any>;
    _subscribe(channel: string, cb: WebSocketSubscribeCallback): WebSocketUnsubscriber;
    _unsubscribe(channel: string, cb?: WebSocketUnsubscribeCallback): void;
    /**
     * Normalize errors
     * Throws a new error based on type of input error
     *
     * @param {AxiosError} e
     */
    private handleError;
    private headers;
}
//# sourceMappingURL=client.d.ts.map